@@ -129,8 +129,6 @@ class BuilderModel:
                 for s in self.software:
                     if s == 'PSPICE': self.buildPSPICE()
                     elif s == 'XYCE': self.buildXYCE()
-                    else:
-                        raise Exception('Please specify software (PSPICE/XYCE).')
 
         ### Case of a conductor model
         elif self.case_model == 'conductor':
@@ -242,8 +240,6 @@ class BuilderModel:
                     Parser = ParserXYCE(self.circuit_data)
                     Parser.readFromYaml(self.file_model_data)
                     self.circuit_data = Parser.circuit_data
-                else:
-                    raise Exception('Please specify software (PSPICE/XYCE).')
         elif self.case_model == 'conductor':
             # Load yaml keys into DataModelConductor dataclass
             self.conductor_data = yaml_to_data(self.file_model_data, DataModelConductor)
