@@ -112,7 +112,7 @@ class Viewer:
 
             # Check that the configuration file exists
             if not os.path.isfile(configuration_file):
-                raise Exception(f'Configuration file {configuration_file} missing.')
+                raise Exception(f'Configuration file {configuration_file} missing. Note that current folder is {os.getcwd()}')
 
             # Read configuration file (note: different events can use different configuration files)
             temp_dict_here = yaml.safe_load(open(configuration_file))
